@@ -74,6 +74,32 @@ void KsnipConfig::setAutoSaveNewCaptures(bool  enabled)
 	saveValue(KsnipConfigOptions::autoSaveNewCapturesString(), enabled);
 }
 
+bool KsnipConfig::autoHideDocks() const
+{
+	return loadValue(KsnipConfigOptions::autoHideDocksString(), false).toBool();
+}
+
+void KsnipConfig::setAutoHideDocks(bool enabled)
+{
+	if (autoHideDocks() == enabled) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::autoHideDocksString(), enabled);
+}
+
+bool KsnipConfig::autoResizeToContent() const
+{
+	return loadValue(KsnipConfigOptions::autoResizeToContentString(), true).toBool();
+}
+
+void KsnipConfig::setAutoResizeToContent(bool enabled)
+{
+	if (autoResizeToContent() == enabled) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::autoResizeToContentString(), enabled);
+}
+
 bool KsnipConfig::useTabs() const
 {
 	return loadValue(KsnipConfigOptions::useTabsString(), true).toBool();
@@ -155,9 +181,9 @@ void KsnipConfig::setCaptureMode(CaptureModes mode)
 
 QString KsnipConfig::saveDirectory() const
 {
-	auto saveDirectoryString = loadValue(KsnipConfigOptions::saveDirectoryString(), QDir::homePath()).toString();
+	auto saveDirectoryString = loadValue(KsnipConfigOptions::saveDirectoryString(), DirectoryPathProvider::home()).toString();
 	if (!saveDirectoryString.isEmpty()) {
-		return saveDirectoryString + QStringLiteral("/");
+		return saveDirectoryString + QLatin1String("/");
     } else {
 		return {};
     }
@@ -173,7 +199,7 @@ void KsnipConfig::setSaveDirectory(const QString& path)
 
 QString KsnipConfig::saveFilename() const
 {
-	auto defaultFilename = QStringLiteral("ksnip_$Y$M$D-$T");
+	auto defaultFilename = QLatin1String("ksnip_$Y$M$D-$T");
 	auto filename = loadValue(KsnipConfigOptions::saveFilenameString(), defaultFilename).toString();
 	if (filename.isEmpty() || filename.isNull()) {
 		filename = defaultFilename;
@@ -192,7 +218,7 @@ void KsnipConfig::setSaveFilename(const QString& filename)
 
 QString KsnipConfig::saveFormat() const
 {
-	auto defaultFormat = QStringLiteral("png");
+	auto defaultFormat = QLatin1String("png");
 	auto format = loadValue(KsnipConfigOptions::saveFormatString(), defaultFormat).toString();
 	if (format.isEmpty() || format.isNull()) {
 		format = defaultFormat;
@@ -211,7 +237,7 @@ void KsnipConfig::setSaveFormat(const QString& format)
 
 QString KsnipConfig::applicationStyle() const
 {
-	auto defaultStyle = QStringLiteral("Fusion");
+	auto defaultStyle = QLatin1String("Fusion");
 	return loadValue(KsnipConfigOptions::applicationStyleString(), defaultStyle).toString();
 }
 
@@ -223,6 +249,32 @@ void KsnipConfig::setApplicationStyle(const QString &style)
 	saveValue(KsnipConfigOptions::applicationStyleString(), style);
 }
 
+TrayIconDefaultActionMode KsnipConfig::defaultTrayIconActionMode() const
+{
+	return loadValue(KsnipConfigOptions::trayIconDefaultActionModeString(), (int)TrayIconDefaultActionMode::ShowEditor).value<TrayIconDefaultActionMode>();
+}
+
+void KsnipConfig::setDefaultTrayIconActionMode(TrayIconDefaultActionMode mode)
+{
+	if (defaultTrayIconActionMode() == mode) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::trayIconDefaultActionModeString(), static_cast<int>(mode));
+}
+
+CaptureModes KsnipConfig::defaultTrayIconCaptureMode() const
+{
+	return loadValue(KsnipConfigOptions::trayIconDefaultCaptureModeString(), (int)CaptureModes::RectArea).value<CaptureModes>();
+}
+
+void KsnipConfig::setDefaultTrayIconCaptureMode(CaptureModes mode)
+{
+	if (defaultTrayIconCaptureMode() == mode) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::trayIconDefaultCaptureModeString(), static_cast<int>(mode));
+}
+
 bool KsnipConfig::useTrayIcon() const
 {
 	return loadValue(KsnipConfigOptions::useTrayIconString(), true).toBool();
@@ -262,6 +314,32 @@ void KsnipConfig::setCloseToTray(bool enabled)
 	saveValue(KsnipConfigOptions::closeToTrayString(), enabled);
 }
 
+bool KsnipConfig::trayIconNotificationsEnabled() const
+{
+	return loadValue(KsnipConfigOptions::trayIconNotificationsEnabledString(), true).toBool();
+}
+
+void KsnipConfig::setTrayIconNotificationsEnabled(bool enabled)
+{
+	if (trayIconNotificationsEnabled() == enabled) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::trayIconNotificationsEnabledString(), enabled);
+}
+
+bool KsnipConfig::platformSpecificNotificationServiceEnabled() const
+{
+	return loadValue(KsnipConfigOptions::platformSpecificNotificationServiceEnabledString(), true).toBool();
+}
+
+void KsnipConfig::setPlatformSpecificNotificationServiceEnabled(bool enabled)
+{
+	if (platformSpecificNotificationServiceEnabled() == enabled) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::platformSpecificNotificationServiceEnabledString(), enabled);
+}
+
 bool KsnipConfig::startMinimizedToTray() const
 {
 	return loadValue(KsnipConfigOptions::startMinimizedToTrayString(), false).toBool();
@@ -385,7 +463,7 @@ void KsnipConfig::setRememberToolSelection(bool enabled)
 
 bool KsnipConfig::switchToSelectToolAfterDrawingItem() const
 {
-	return loadValue(KsnipConfigOptions::switchToSelectToolAfterDrawingItemString(), false).toBool();
+	return loadValue(KsnipConfigOptions::switchToSelectToolAfterDrawingItemString(), true).toBool();
 }
 
 void KsnipConfig::setSwitchToSelectToolAfterDrawingItem(bool enabled)
@@ -397,106 +475,31 @@ void KsnipConfig::setSwitchToSelectToolAfterDrawingItem(bool enabled)
 	emit annotatorConfigChanged();
 }
 
-bool KsnipConfig::textBold() const
+bool KsnipConfig::selectItemAfterDrawing() const
 {
-    return textFont().bold();
+	return loadValue(KsnipConfigOptions::selectItemAfterDrawingString(), true).toBool();
 }
 
-void KsnipConfig::setTextBold(bool  bold)
+void KsnipConfig::setSelectItemAfterDrawing(bool enabled)
 {
-    if (textBold() == bold) {
-        return;
-    }
-    auto font = textFont();
-    font.setBold(bold);
-
-	saveValue(KsnipConfigOptions::textFontString(), font);
+	if (selectItemAfterDrawing() == enabled) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::selectItemAfterDrawingString(), enabled);
 	emit annotatorConfigChanged();
 }
 
-bool KsnipConfig::textItalic() const
+bool KsnipConfig::numberToolSeedChangeUpdatesAllItems() const
 {
-    return textFont().italic();
+	return loadValue(KsnipConfigOptions::numberToolSeedChangeUpdatesAllItemsString(), true).toBool();
 }
 
-void KsnipConfig::setTextItalic(bool  italic)
+void KsnipConfig::setNumberToolSeedChangeUpdatesAllItems(bool enabled)
 {
-    if (textItalic() == italic) {
-        return;
-    }
-    auto font = textFont();
-    font.setItalic(italic);
-
-	saveValue(KsnipConfigOptions::textFontString(), font);
-	emit annotatorConfigChanged();
-}
-
-bool KsnipConfig::textUnderline() const
-{
-    return textFont().underline();
-}
-
-void KsnipConfig::setTextUnderline(bool  underline)
-{
-    if (textUnderline() == underline) {
-        return;
-    }
-    auto font = textFont();
-    font.setUnderline(underline);
-
-	saveValue(KsnipConfigOptions::textFontString(), font);
-	emit annotatorConfigChanged();
-}
-
-QFont KsnipConfig::textFont() const
-{
-	auto defaultFont = QFont(QStringLiteral("Arial"), 12);
-	return loadValue(KsnipConfigOptions::textFontString(), defaultFont).value<QFont>();
-}
-
-void KsnipConfig::setTextFont(const QFont& font)
-{
-    if (textFont().family() == font.family()) {
-        return;
-    }
-    auto tmpFont = textFont();
-    tmpFont.setFamily(font.family());
-
-	saveValue(KsnipConfigOptions::textFontString(), tmpFont);
-	emit annotatorConfigChanged();
-}
-
-QFont KsnipConfig::numberFont() const
-{
-	auto defaultFont = QFont(QStringLiteral("Comic Sans MS"), 30, QFont::Bold);
-	return loadValue(KsnipConfigOptions::numberFontString(), defaultFont).value<QFont>();
-}
-
-void KsnipConfig::setNumberFont(const QFont& font)
-{
-    if (numberFont().family() == font.family()) {
-        return;
-    }
-    auto tmpFont = numberFont();
-    tmpFont.setFamily(font.family());
-    tmpFont.setBold(true);
-
-	saveValue(KsnipConfigOptions::numberFontString(), tmpFont);
-	emit annotatorConfigChanged();
-}
-
-bool KsnipConfig::itemShadowEnabled() const
-{
-	return loadValue(KsnipConfigOptions::itemShadowEnabledString(), true).toBool();
-}
-
-void KsnipConfig::setItemShadowEnabled(bool enabled)
-{
-    if (itemShadowEnabled() == enabled) {
-        return;
-    }
-
-	saveValue(KsnipConfigOptions::itemShadowEnabledString(), enabled);
+	if (numberToolSeedChangeUpdatesAllItems() == enabled) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::numberToolSeedChangeUpdatesAllItemsString(), enabled);
 	emit annotatorConfigChanged();
 }
 
@@ -574,6 +577,21 @@ void KsnipConfig::setUseDefaultSticker(bool enabled)
 	emit annotatorConfigChanged();
 }
 
+QColor KsnipConfig::canvasColor() const
+{
+	return loadValue(KsnipConfigOptions::canvasColorString(), QColor(Qt::white)).value<QColor>();
+}
+
+void KsnipConfig::setCanvasColor(const QColor &color)
+{
+	if (canvasColor() == color) {
+		return;
+	}
+
+	saveValue(KsnipConfigOptions::canvasColorString(), color);
+	emit annotatorConfigChanged();
+}
+
 // Image Grabber
 
 bool KsnipConfig::isFreezeImageWhileSnippingEnabledReadOnly() const
@@ -704,6 +722,32 @@ void KsnipConfig::setSnippingCursorColor(const QColor& color)
 	saveValue(KsnipConfigOptions::snippingCursorColorString(), color);
 }
 
+QColor KsnipConfig::snippingAdornerColor() const
+{
+	return loadValue(KsnipConfigOptions::snippingAdornerColorString(), QColor(Qt::red)).value<QColor>();
+}
+
+void KsnipConfig::setSnippingAdornerColor(const QColor& color)
+{
+	if (snippingAdornerColor() == color) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::snippingAdornerColorString(), color);
+}
+
+int KsnipConfig::snippingAreaTransparency() const
+{
+	return loadValue(KsnipConfigOptions::snippingAreaTransparencyString(), 150).value<int>();
+}
+
+void KsnipConfig::setSnippingAreaTransparency(int transparency)
+{
+	if (snippingAreaTransparency() == transparency) {
+		return;
+	}
+	saveValue(KsnipConfigOptions::snippingAreaTransparencyString(), transparency);
+}
+
 QRect KsnipConfig::lastRectArea() const
 {
 	return loadValue(KsnipConfigOptions::lastRectAreaString(), QRect()).value<QRect>();
@@ -785,7 +829,7 @@ void KsnipConfig::setUploaderType(UploaderType type)
 
 QString KsnipConfig::imgurUsername() const
 {
-	auto defaultUsername = QStringLiteral("");
+	auto defaultUsername = QLatin1String("");
 	return loadValue(KsnipConfigOptions::imgurUsernameString(), defaultUsername).toString();
 }
 
@@ -799,7 +843,7 @@ void KsnipConfig::setImgurUsername(const QString& username)
 
 QByteArray KsnipConfig::imgurClientId() const
 {
-	auto defaultClientId = QStringLiteral("");
+	auto defaultClientId = QLatin1String("");
 	return loadValue(KsnipConfigOptions::imgurClientIdString(), defaultClientId).toByteArray();
 }
 
@@ -813,7 +857,7 @@ void KsnipConfig::setImgurClientId(const QString& clientId)
 
 QByteArray KsnipConfig::imgurClientSecret() const
 {
-	auto defaultClientSecret = QStringLiteral("");
+	auto defaultClientSecret = QLatin1String("");
 	return loadValue(KsnipConfigOptions::imgurClientSecretString(), defaultClientSecret).toByteArray();
 }
 
@@ -827,7 +871,7 @@ void KsnipConfig::setImgurClientSecret(const QString& clientSecret)
 
 QByteArray KsnipConfig::imgurAccessToken() const
 {
-	auto defaultAccessToken = QStringLiteral("");
+	auto defaultAccessToken = QLatin1String("");
 	return loadValue(KsnipConfigOptions::imgurAccessTokenString(), defaultAccessToken).toByteArray();
 }
 
@@ -841,7 +885,7 @@ void KsnipConfig::setImgurAccessToken(const QString& accessToken)
 
 QByteArray KsnipConfig::imgurRefreshToken() const
 {
-	auto defaultRefreshToken = QStringLiteral("");
+	auto defaultRefreshToken = QLatin1String("");
 	return loadValue(KsnipConfigOptions::imgurRefreshTokenString(), defaultRefreshToken).toByteArray();
 }
 
@@ -1092,6 +1136,67 @@ void KsnipConfig::setPortalHotKey(const QKeySequence &keySequence)
     emit hotKeysChanged();
 }
 
+// Actions
+
+QList<Action> KsnipConfig::actions()
+{
+	QList<Action> actions;
+	auto count = mConfig.beginReadArray(KsnipConfigOptions::actionsString());
+	for (auto index = 0; index < count; index++) {
+		mConfig.setArrayIndex(index);
+		Action action;
+		action.setName(mConfig.value(KsnipConfigOptions::actionNameString()).toString());
+		action.setShortcut(mConfig.value(KsnipConfigOptions::actionShortcutString()).value<QKeySequence>());
+		action.setIsCaptureEnabled(mConfig.value(KsnipConfigOptions::actionIsCaptureEnabledString()).toBool());
+		action.setIncludeCursor(mConfig.value(KsnipConfigOptions::actionIncludeCursorString()).toBool());
+		action.setCaptureDelay(mConfig.value(KsnipConfigOptions::actionCaptureDelayString()).toInt());
+		action.setCaptureMode(mConfig.value(KsnipConfigOptions::actionCaptureModeString()).value<CaptureModes>());
+		action.setIsPinScreenshotEnabled(mConfig.value(KsnipConfigOptions::actionIsPinImageEnabledString()).toBool());
+		action.setIsUploadEnabled(mConfig.value(KsnipConfigOptions::actionIsUploadEnabledString()).toBool());
+		action.setIsOpenDirectoryEnabled(mConfig.value(KsnipConfigOptions::actionIsOpenDirectoryEnabledString()).toBool());
+		action.setIsCopyToClipboardEnabled(mConfig.value(KsnipConfigOptions::actionIsCopyToClipboardEnabledString()).toBool());
+		action.setIsSaveEnabled(mConfig.value(KsnipConfigOptions::actionIsSaveEnabledString()).toBool());
+		action.setIsHideMainWindowEnabled(mConfig.value(KsnipConfigOptions::actionIsHideMainWindowEnabledString()).toBool());
+		actions.append(action);
+	}
+	mConfig.endArray();
+	return actions;
+}
+
+void KsnipConfig::setActions(const QList<Action> &actions)
+{
+	auto savedActions = this->actions();
+
+	if(savedActions == actions) {
+		return;
+	}
+
+	mConfig.remove(KsnipConfigOptions::actionsString());
+
+	auto count = actions.count();
+	mConfig.beginWriteArray(KsnipConfigOptions::actionsString());
+	for (auto index = 0; index < count; ++index) {
+		const auto& action = actions.at(index);
+		mConfig.setArrayIndex(index);
+		mConfig.setValue(KsnipConfigOptions::actionNameString(), action.name());
+		mConfig.setValue(KsnipConfigOptions::actionShortcutString(), action.shortcut());
+		mConfig.setValue(KsnipConfigOptions::actionIsCaptureEnabledString(), action.isCaptureEnabled());
+		mConfig.setValue(KsnipConfigOptions::actionIncludeCursorString(), action.includeCursor());
+		mConfig.setValue(KsnipConfigOptions::actionCaptureDelayString(), action.captureDelay());
+		mConfig.setValue(KsnipConfigOptions::actionCaptureModeString(), static_cast<int>(action.captureMode()));
+		mConfig.setValue(KsnipConfigOptions::actionIsPinImageEnabledString(), action.isPinImageEnabled());
+		mConfig.setValue(KsnipConfigOptions::actionIsUploadEnabledString(), action.isUploadEnabled());
+		mConfig.setValue(KsnipConfigOptions::actionIsOpenDirectoryEnabledString(), action.isOpenDirectoryEnabled());
+		mConfig.setValue(KsnipConfigOptions::actionIsCopyToClipboardEnabledString(), action.isCopyToClipboardEnabled());
+		mConfig.setValue(KsnipConfigOptions::actionIsSaveEnabledString(), action.isSaveEnabled());
+		mConfig.setValue(KsnipConfigOptions::actionIsHideMainWindowEnabledString(), action.isHideMainWindowEnabled());
+	}
+	mConfig.endArray();
+
+	emit actionsChanged();
+	emit hotKeysChanged();
+}
+
 // Misc
 
 void KsnipConfig::saveValue(const QString &key, const QVariant &value)
