@@ -25,33 +25,103 @@
     </message>
     <message>
         <source>Donate</source>
-        <translation>Contributo económico</translation>
+        <translation>Dona</translation>
+    </message>
+    <message>
+        <source>Contact</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>AboutTab</name>
-    <message>
-        <source>Screenshot Tool</source>
-        <translation>Applicazione per la cattura di schermate</translation>
-    </message>
     <message>
         <source>License: </source>
         <translation>Licenza: </translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Usa </translation>
+        <source>Screenshot and Annotation Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionSettingTab</name>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> per segnalare malfunzionamenti.</translation>
+        <source>Shortcut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Take Capture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include Cursor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>s</source>
+        <translation type="unfinished">s</translation>
+    </message>
+    <message>
+        <source>Capture Mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show image in Pin Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy image to Clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open image parent directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Main Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ActionsSettings</name>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Actions Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Action</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>AddWatermarkOperation</name>
     <message>
         <source>Watermark Image Required</source>
-        <translation>Immagine filigrana Necessaria</translation>
+        <translation>Immagine filigrana necessaria</translation>
     </message>
     <message>
         <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
@@ -60,14 +130,6 @@
 </context>
 <context>
     <name>AnnotationSettings</name>
-    <message>
-        <source>Paint Item Shadows</source>
-        <translation>Aggiungere ombre all&apos;oggetto</translation>
-    </message>
-    <message>
-        <source>When enabled, paint items cast shadows.</source>
-        <translation>Se abilitato, gli elementi aggiunti avranno delle ombre.</translation>
-    </message>
     <message>
         <source>Smooth Painter Paths</source>
         <translation>Smussa i tratti di pennello</translation>
@@ -88,50 +150,6 @@ precision for pen and marker but will
 make them more smooth.</source>
         <translation>All&apos;aumentare del fattore di smussamento diminuirà la precisione, ma aumenterà la levigazione del tratto di penna/pennarello.</translation>
     </message>
-    <message>
-        <source>Text Font</source>
-        <translation>Font di testo</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Text Paint Item.</source>
-        <translation>Imposta il font per lo strumento di testo.</translation>
-    </message>
-    <message>
-        <source>Bold</source>
-        <translation>Grassetto</translation>
-    </message>
-    <message>
-        <source>Italic</source>
-        <translation>Corsivo</translation>
-    </message>
-    <message>
-        <source>Underline</source>
-        <translation>Sottolineato</translation>
-    </message>
-    <message>
-        <source>Numbering Font</source>
-        <translation>Font di numerazione</translation>
-    </message>
-    <message>
-        <source>Sets the font for the Numbering Paint Item.</source>
-        <translation>Imposta il font per lo strumento di numerazione.</translation>
-    </message>
-    <message>
-        <source>Watermark Image</source>
-        <translation>Immagine di filigrana</translation>
-    </message>
-    <message>
-        <source>Update</source>
-        <translation>Aggiorna</translation>
-    </message>
-    <message>
-        <source>Rotate Watermark</source>
-        <translation>Ruota immagine</translation>
-    </message>
-    <message>
-        <source>When enabled, Watermark will be added with a rotation of 45°</source>
-        <translation>Se abilitato, l&apos;immagine verrà aggiunta con una rotazione di 45°</translation>
-    </message>
     <message>
         <source>Annotator Settings</source>
         <translation>Impostazioni Annotatore</translation>
@@ -144,6 +162,34 @@ make them more smooth.</source>
         <source>Switch to Select Tool after drawing Item</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number Tool Seed change updates all Number Items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disabling this option causes changes of the number tool
+seed to affect only new items but not existing items.
+Disabling this option allows having duplicate numbers.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Canvas Color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Canvas background color for annotation area.
+Changing color affects only new annotation areas.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Item after drawing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>With this option enabled the item gets selected after
+being created, allowing changing settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ApplicationSettings</name>
@@ -151,24 +197,6 @@ make them more smooth.</source>
         <source>Capture screenshot at startup with default mode</source>
         <translation>Salva una schermata all&apos;avvio usando la modalità di default</translation>
     </message>
-    <message>
-        <source>Use Tray Icon</source>
-        <translation>Mostra icona nel vassoio di sistema</translation>
-    </message>
-    <message>
-        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
-Change requires restart.</source>
-        <translation>Se abilitato, mostrerà un&apos;icona nel vassoio di sistema se il DE lo supporta.
-Questa impostazione richiede il riavvio.</translation>
-    </message>
-    <message>
-        <source>Minimize to Tray</source>
-        <translation>Minimizza nel vassoio</translation>
-    </message>
-    <message>
-        <source>Close to Tray</source>
-        <translation>Chiudi nel vassoio</translation>
-    </message>
     <message>
         <source>Application Style</source>
         <translation>Stile applicazione</translation>
@@ -185,11 +213,7 @@ Questa impostazione richiede il riavvio.</translation>
     </message>
     <message>
         <source>Automatically copy new captures to clipboard</source>
-        <translation>Copia automaticamente le nuove acquisizioni negli appunti</translation>
-    </message>
-    <message>
-        <source>Auto Hide Tabs</source>
-        <translation>Nascondi le schede automaticamente</translation>
+        <translation>Copia automaticamente le nuove catture negli appunti</translation>
     </message>
     <message>
         <source>Use Tabs</source>
@@ -203,10 +227,6 @@ Questa impostazione richiede il riavvio.</translation>
         <source>Run ksnip as single instance</source>
         <translation>Usa ksnip in una sola finestra</translation>
     </message>
-    <message>
-        <source>Start Minimized to Tray</source>
-        <translation>Iniziare minimizzato nella barra delle applicazione</translation>
-    </message>
     <message>
         <source>Hide Tabbar when only one Tab is used.</source>
         <translation type="unfinished"></translation>
@@ -222,13 +242,30 @@ a new start of all instances.</source>
         <source>Remember Main Window position on move and load on startup</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Auto hide Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>On startup hide Toolbar and Annotation Settings.
+Docks visibility can be toggled with the Tab Key.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto resize to content</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically resize Main Window to fit content image.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
-    <message>
-        <source>The Author:</source>
-        <translation>Autore:</translation>
-    </message>
     <message>
         <source>Contributors:</source>
         <translation>Collaboratori:</translation>
@@ -262,7 +299,7 @@ a new start of all instances.</source>
         <translation>Versione Snap &amp; Flatpack</translation>
     </message>
     <message>
-        <source>Feature Implementation</source>
+        <source>The Authors:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -285,60 +322,82 @@ Vuoi salvarla?</translation>
         <source>New</source>
         <translation>Nuovo</translation>
     </message>
-    <message>
-        <source>Rectangular Area</source>
-        <translation>Area rettangolare</translation>
-    </message>
     <message>
         <source>Draw a rectangular area with your mouse</source>
         <translation>Traccia un&apos;area rettangolare con il mouse</translation>
     </message>
-    <message>
-        <source>Last Rectangular Area</source>
-        <translation>Ultima area rettangolare usata</translation>
-    </message>
     <message>
         <source>Capture a screenshot of the last selected rectangular area</source>
         <translation>Cattura usando la ultima area rettangolare usata</translation>
     </message>
-    <message>
-        <source>Full Screen (All Monitors)</source>
-        <translation>Schermo completo (tutti gli schermi)</translation>
-    </message>
     <message>
         <source>Capture full screen including all monitors</source>
         <translation>Cattura di tutti gli schermi collegati</translation>
     </message>
-    <message>
-        <source>Current Screen</source>
-        <translation>Schermo attuale</translation>
-    </message>
     <message>
         <source>Capture screen where the mouse is located</source>
         <translation>Acquisisci lo schermo nella posizione del mouse</translation>
     </message>
-    <message>
-        <source>Active Window</source>
-        <translation>Finestra attiva</translation>
-    </message>
     <message>
         <source>Capture window that currently has focus</source>
         <translation>Acquisisci la finestra attualmente in primo piano</translation>
     </message>
-    <message>
-        <source>Window Under Cursor</source>
-        <translation>Finestra sotto il cursore</translation>
-    </message>
     <message>
         <source>Capture that is currently under the mouse cursor</source>
         <translation>Cattura ciò che si trova attualmente sotto il cursore del mouse</translation>
     </message>
     <message>
-        <source>Screenshot Portal</source>
+        <source>Uses the screenshot Portal for taking screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ContactTab</name>
+    <message>
+        <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Uses the screenshot Portal for taking screenshot</source>
+        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>please join our </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> server.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bug Reports</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please use </source>
+        <translation type="unfinished">Usa </translation>
+    </message>
+    <message>
+        <source> to report bugs.</source>
+        <translation type="unfinished"> per segnalare malfunzionamenti.</translation>
+    </message>
+</context>
+<context>
+    <name>CopyAsDataUriOperation</name>
+    <message>
+        <source>Failed to copy to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to copy to clipboard as base64 encoded image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copied to clipboard as base64 encoded image.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -370,7 +429,7 @@ Do you want to continue?</source>
     </message>
     <message>
         <source>Donation</source>
-        <translation type="unfinished"></translation>
+        <translation>Donazione</translation>
     </message>
     <message>
         <source>Become a GitHub Sponsor</source>
@@ -385,6 +444,44 @@ Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>EmptyActionSettingTab</name>
+    <message>
+        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>EnumTranslator</name>
+    <message>
+        <source>Rectangular Area</source>
+        <translation>Area rettangolare</translation>
+    </message>
+    <message>
+        <source>Last Rectangular Area</source>
+        <translation type="unfinished">Ultima area rettangolare usata</translation>
+    </message>
+    <message>
+        <source>Full Screen (All Monitors)</source>
+        <translation type="unfinished">Schermo completo (tutti gli schermi)</translation>
+    </message>
+    <message>
+        <source>Current Screen</source>
+        <translation type="unfinished">Schermo attuale</translation>
+    </message>
+    <message>
+        <source>Active Window</source>
+        <translation type="unfinished">Finestra attiva</translation>
+    </message>
+    <message>
+        <source>Window Under Cursor</source>
+        <translation type="unfinished">Finestra sotto il cursore</translation>
+    </message>
+    <message>
+        <source>Screenshot Portal</source>
+        <translation>Portale schermate</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
@@ -450,10 +547,6 @@ Do you want to continue?</source>
         <source>Enable Global HotKeys</source>
         <translation>Abilita scorciatoie globali</translation>
     </message>
-    <message>
-        <source>HotKeys are currently supported only for Windows and X11</source>
-        <translation>Le scorciatoie sono attualmente supportate solo su Windows e X11</translation>
-    </message>
     <message>
         <source>Capture Rect Area</source>
         <translation>Acquisisci area rettangolare</translation>
@@ -490,6 +583,11 @@ Do you want to continue?</source>
         <source>Capture using Portal</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>HotKeys are currently supported only for Windows and X11.
+Disabling this option makes also the action shortcuts ksnip only.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImageGrabberSettings</name>
@@ -503,64 +601,10 @@ screenshots.</source>
         <translation>Il cursore del mouse dovrebbe essere visibile su
 screenshot.</translation>
     </message>
-    <message>
-        <source>Freeze Image while snipping</source>
-        <translation>Blocca l&apos;immagine durante lo snipping</translation>
-    </message>
-    <message>
-        <source>Show magnifying glass on snipping area</source>
-        <translation>Mostra la lente d&apos;ingrandimento sull&apos;area di cattura</translation>
-    </message>
-    <message>
-        <source>Show a magnifying glass which zooms into
-the background image. This option only works
-with &apos;Freeze Image while snipping&apos; enabled.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show Snipping Area rulers</source>
-        <translation>Mostra righelli area di cattura</translation>
-    </message>
-    <message>
-        <source>Horizontal and vertical lines going from
-desktop edges to cursor on snipping area.</source>
-        <translation>Linee orizzontali e verticali che vanno da
-bordi del desktop per il cursore sull&apos;area di cattura.</translation>
-    </message>
-    <message>
-        <source>Show Snipping Area position and size info</source>
-        <translation>Mostra le informazioni sulla posizione e sulla dimensione dell&apos;area di cattura</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor color</source>
-        <translation>Colore del cursore dell&apos;area di cattura</translation>
-    </message>
-    <message>
-        <source>Snipping Area cursor thickness</source>
-        <translation>Spessore cursore area di cattura</translation>
-    </message>
     <message>
         <source>Image Grabber</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>When enabled will freeze the background while
-selecting a rectangular region. It also changes
-the behavior of delayed screenshots, with this
-option enabled the delay happens before the
-snipping area is shown and with the option disabled
-the delay happens after the snipping area is shown.
-This feature is always disabled for Wayland and always
-enabled for MacOs.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When left mouse button is not pressed the position
-is shown, when the mouse button is pressed,
-the size of the select area is shown left
-and above from the captured area.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Force Generic Wayland Screenshot</source>
         <translation type="unfinished"></translation>
@@ -589,22 +633,6 @@ Change in this option require a ksnip restart.</source>
         <source>Show Main Window after capturing screenshot</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Show Main Window after capturing a new screenshot
-when the Main Window was hidden or minimized.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Allow resizing rect area selection</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>When enabled will, after selecting a rect
-area, allow resizing the selection. When
-done resizing the selection can be confirmed
-by pressing return.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Hide Main Window during screenshot</source>
         <translation type="unfinished"></translation>
@@ -614,11 +642,8 @@ by pressing return.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Sets the color of the snipping area cursor.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sets the thickness of the snipping area cursor.</source>
+        <source>Show Main Window after capturing a new screenshot
+when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -714,10 +739,6 @@ by pressing return.</source>
         <source>Waiting for imgur.com…</source>
         <translation>In attesa di imgur.com...</translation>
     </message>
-    <message>
-        <source>Username:</source>
-        <translation>Nome Utente:</translation>
-    </message>
     <message>
         <source>Imgur.com token successfully updated.</source>
         <translation>Token Imgur.com aggiornato correttamente.</translation>
@@ -739,6 +760,21 @@ by pressing return.</source>
 Changing requires restart.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clear Token</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoadImageFromFileOperation</name>
+    <message>
+        <source>Unable to open image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open image from path %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainToolBar</name>
@@ -827,10 +863,6 @@ e cattura screenshot.</translation>
         <source>Scale</source>
         <translation>Scala</translation>
     </message>
-    <message>
-        <source>Scale Screen Capture</source>
-        <translation>Scala Cattura Schermo</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Aggiungi Filigrana</translation>
@@ -887,10 +919,6 @@ e cattura screenshot.</translation>
         <source>Paste Embedded</source>
         <translation type="unfinished">Incollaggio Incorporato</translation>
     </message>
-    <message>
-        <source>Upload capture to external source</source>
-        <translation>Carica l&apos;acquisizione su una fonte esterna</translation>
-    </message>
     <message>
         <source>Pin</source>
         <translation type="unfinished"></translation>
@@ -927,6 +955,46 @@ e cattura screenshot.</translation>
         <source>Open Images</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide Docks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy as data URI</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open &amp;Recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify Canvas</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload triggerCapture to external source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy triggerCapture to system clipboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1203,6 +1271,174 @@ When omitted, everything is copied.</source>
         <source>Stickers</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Watermark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaResizerInfoText</name>
+    <message>
+        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys to move the selection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSelectorInfoText</name>
+    <message>
+        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to resize selection after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Operation will be canceled after 60 sec when no selection made.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This message can be disabled via settings.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SnippingAreaSettings</name>
+    <message>
+        <source>Freeze Image while snipping</source>
+        <translation type="unfinished">Blocca l&apos;immagine durante lo snipping</translation>
+    </message>
+    <message>
+        <source>When enabled will freeze the background while
+selecting a rectangular region. It also changes
+the behavior of delayed screenshots, with this
+option enabled the delay happens before the
+snipping area is shown and with the option disabled
+the delay happens after the snipping area is shown.
+This feature is always disabled for Wayland and always
+enabled for MacOs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show magnifying glass on snipping area</source>
+        <translation type="unfinished">Mostra la lente d&apos;ingrandimento sull&apos;area di cattura</translation>
+    </message>
+    <message>
+        <source>Show a magnifying glass which zooms into
+the background image. This option only works
+with &apos;Freeze Image while snipping&apos; enabled.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Snipping Area rulers</source>
+        <translation type="unfinished">Mostra righelli area di cattura</translation>
+    </message>
+    <message>
+        <source>Horizontal and vertical lines going from
+desktop edges to cursor on snipping area.</source>
+        <translation type="unfinished">Linee orizzontali e verticali che vanno da
+bordi del desktop per il cursore sull&apos;area di cattura.</translation>
+    </message>
+    <message>
+        <source>Show Snipping Area position and size info</source>
+        <translation type="unfinished">Mostra le informazioni sulla posizione e sulla dimensione dell&apos;area di cattura</translation>
+    </message>
+    <message>
+        <source>When left mouse button is not pressed the position
+is shown, when the mouse button is pressed,
+the size of the select area is shown left
+and above from the captured area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow resizing rect area selection by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will, after selecting a rect
+area, allow resizing the selection. When
+done resizing the selection can be confirmed
+by pressing return.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Snipping Area info text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor color</source>
+        <translation type="unfinished">Colore del cursore dell&apos;area di cattura</translation>
+    </message>
+    <message>
+        <source>Sets the color of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area cursor thickness</source>
+        <translation type="unfinished">Spessore cursore area di cattura</translation>
+    </message>
+    <message>
+        <source>Sets the thickness of the snipping area cursor.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area adorner color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sets the color of all adorner elements
+on the snipping area.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Snipping Area Transparency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alpha for not selected region on snipping area.
+Smaller number is more transparent.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StickerSettings</name>
@@ -1246,6 +1482,64 @@ When omitted, everything is copied.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>TrayIconSettings</name>
+    <message>
+        <source>Use Tray Icon</source>
+        <translation type="unfinished">Mostra icona nel vassoio di sistema</translation>
+    </message>
+    <message>
+        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
+Change requires restart.</source>
+        <translation type="unfinished">Se abilitato, mostrerà un&apos;icona nel vassoio di sistema se il DE lo supporta.
+Questa impostazione richiede il riavvio.</translation>
+    </message>
+    <message>
+        <source>Minimize to Tray</source>
+        <translation type="unfinished">Minimizza nel vassoio</translation>
+    </message>
+    <message>
+        <source>Start Minimized to Tray</source>
+        <translation type="unfinished">Iniziare minimizzato nella barra delle applicazione</translation>
+    </message>
+    <message>
+        <source>Close to Tray</source>
+        <translation type="unfinished">Chiudi nel vassoio</translation>
+    </message>
+    <message>
+        <source>Show Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Capture</source>
+        <translation type="unfinished">Cattura</translation>
+    </message>
+    <message>
+        <source>Default Tray Icon action</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default Action that is triggered by left clicking the tray icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tray Icon Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display Tray icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use platform specific notification service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When enabled will use try to use platform specific notification
+service when such exists. Change requires restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>UpdateWatermarkOperation</name>
     <message>
@@ -1318,4 +1612,27 @@ When omitted, everything is copied.</source>
         <translation type="unfinished">Utilizza:</translation>
     </message>
 </context>
+<context>
+    <name>WatermarkSettings</name>
+    <message>
+        <source>Watermark Image</source>
+        <translation type="unfinished">Immagine di filigrana</translation>
+    </message>
+    <message>
+        <source>Update</source>
+        <translation type="unfinished">Aggiorna</translation>
+    </message>
+    <message>
+        <source>Rotate Watermark</source>
+        <translation type="unfinished">Ruota immagine</translation>
+    </message>
+    <message>
+        <source>When enabled, Watermark will be added with a rotation of 45°</source>
+        <translation type="unfinished">Se abilitato, l&apos;immagine verrà aggiunta con una rotazione di 45°</translation>
+    </message>
+    <message>
+        <source>Watermark Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
